@@ -47,6 +47,7 @@ macro_rules! detest {
   ($fn_name:ident, $t:ty, $src:expr, $rust:expr) => {
     #[test]
     fn $fn_name() {
+      #[allow(clippy::bool_assert_comparison)]
       dedo($src, |scope, v| {
         let rt = serde_v8::from_v8(scope, v);
         assert!(rt.is_ok(), "from_v8(\"{}\"): {:?}", $src, rt.err());
@@ -221,3 +222,5 @@ detest!(
     .collect()
   )
 );
+detest!(de_bigint_u64, u64, "BigInt(2**59)", 1 << 59);
+detest!(de_bigint_i64, i64, "BigInt(-(2**59))", -(1 << 59));
